@@ -4,7 +4,7 @@ eds1 <- function(x, q=1, retq = TRUE) {
 		sum(-x*log(x),na.rm=TRUE)
 	}
 	x[x!=0] <- x[x!=0]^q
-	if (!is.null(dim(x))) a <- apply(x,1,eds1)
+	if (!is.null(dim(x))) a <- apply(x,1,eds1,retq=retq)
 	else {
 		x <- matrix(x,nrow=1)
 		rs <- sum(x)
